# Chinese

## Introduction

Chinese astronomy was developed independently and use its own system to connect
the stars. The traditional Chinese Sky Culture has far-reaching implications in
East Asia. In ancient China, constellations and planets were associated with
astrology.

## Description

### Asterisms (Xingguans)

In traditional Chinese astronomy stars are grouped to form asterisms, known as
"Xingguan" (Chinese: 星官, xīngguān, meaning "Star officials"). Xinguuans have
names and shapes related to elements of the ancient Chinese society such as the
kingdom, the mountains, the goods or the industry. They are in a way projecting
the world of humans into the sky.

Xingguans can contain from one to several dozens of stars. Most of them
are smaller than the constellations of Hellenistic tradition. In the Song
dynasty (13th century), the Suzhou astronomical map [#3] was engraved in
marble. It shows a total of 283 Xingguans, comprising a total of 1,565
individual stars divided into 31 regions: the 28 lunar mansions along the
ecliptic, and the 3 enclosures of the northern sky.

![](suzhouskxt.webp)
The astronomical map of Suzhou, engraved in black marble (1247)
{: .img_and_caption }

Due to precession, six Xingguans near the southern horizon became difficult to
observe and were not included in the Suzhou map. Before the Ming dynasty,
Xingguans did not include the sky around the celestial south pole. The Southern
Asterisms were added as a fifth group in the late Ming dynasty based on
European star charts, defining an additional 23 Xingguans [#11].

### Sun, Moon and Planets

For ancient Chinese, the Sun, the Moon and the five planets form _Seven
Luminaries_ (Chinese: 七曜, qīyào), which correspond to the Yin, the Yang and the
Five Elements. The wood is green, the fire is red, the earth is yellow, the
metal is white, the water is black. So, Mercury is named Water Star, Venus is
named Metal Star, Mars is named Fire Star, Jupiter is named Wood Star,
Saturn is named Earth Star.

The Sun and the Moon are named Taiyang (Sun, Chinese: 太阳) and Taiyin (Moon,
Chinese: 太阴) composed from the words "tài" (Great, Chinese: 太) and "Yin" or
"Yang". Their other name belongs to pictographic characters Ri (Sun, Chinese:
日) and Yue (Moon, Chinese: 月) but the more commonly used name for the moon is
Yueliang (Chinese: 月亮, yuèliàng).

### Star names

The naming of stars in ancient China is composed of the name of the Xingguan
plus a number. Some stars also have a common name, such as Alpha Leonis which
is called "the Queen's Star".

Unlike Xingguans, traditional Chinese star names are still in common usage
today, even more common than Bayer/Flamsteed designations.

### The three Enclosures

The 3 enclosures are regions containing smaller asterisms. The enclosure of the
Purple Forbidden Palace (Chinese: 紫微垣, Zǐwēi yuán) surrounds almost the whole
circumpolar area while the enclosures of the Supreme Palace (Chinese: 太微垣,
Tàiwēi yuán) and the Heavenly Market (Chinese: 天市垣, Tiānshì yuán) are located
close to the ecliptic.

Each enclosure has two walls, called the left wall and the right wall which are
the main Xingguans. Some Xingguans are located within these "wall" (such as
Guards of the Palace), others are located in the area that they are
surrounding. For example, the Xingguans of the Emperor and of the Crown Prince
are located inside the Xingguan of the Forbidden Palace.

The enclosure of Purple Forbidden Palace [#7] represents the inner palace of
the emperor because the whole celestial sphere with all other Xingguans is
turning around this polar region. In the ancient Chinese belief, the Purple
Forbidden Palace lies in the middle of the sky and covers the modern
constellations Ursa Minor, Draco, Camelopardalis, Cepheus, Cassiopeia, Auriga,
Boötes, and parts of Ursa Major, Canes Venatici, Leo Minor, Hercules. It
contains 37 traditional Xingguans.

The enclosure of the Supreme Palace [#8] is the place where the emperor and the
courtiers deal with their politics. The Supreme Palace includes a variety of
officials and government agencies, a total of 20 traditional Xingguans. It
covers the modern constellations Virgo, Coma Berenices and Leo, and parts of
Canes Venatici, Ursa Major and Leo Minor.

Heavenly Market enclosure [#9] is a bazaar in the sky, a place where ordinary
people meet and are represented with their bazaar facilities in 19 Xingguans.
The Heavenly Market Place covers the modern constellations Serpens, Ophiuchus,
Aquila and Corona Borealis, and parts of Hercules.

### Twenty-Eight Lunar Mansions

The 28 Lunar Mansions (Chinese: 宿, xiù) [#10] are slices of right ascensions in
the path of the Moon around the ecliptic. The lunar mansion asterisms are not
of equal size: there are 28 constellations north and south of the ecliptic but
the regions of the Xiú (mansions) extend from there towards the equatorial pole
where the right ascension lines intersect. The inital intention was to define
the mansions in a way so that the Moon changes of mansion every day but due to
variability of the orbit and speed of the Moon, this concept does not apply any
more. The smallest slice extends on only 1° of right ascension.

## Extras

### Notes on star names

There can be more than one way of numbering the stars within one
asterism, thus, there can be more than one "name" for a certain star. For
example, "the Queen's Star" is also referred to as "Xuanyuan 14" or (rarely)
"Xuanyuan 1". The number depending on the purpose (normal astronomy or
observation of the Moon's path).

In the traditional Chinese catalogues before 1650, coordinates were only given
for one star per constellation, the so called main star or principle star [#1].
This is the star with the number "1" in the constellation where counting is
started. It is usually the star with the westernmost right ascension.

The Suzhou map [#3] is based on coordinates and asterisms defined in antiquity
which became canonical [#1],[#2] but later further stars were added. These are
called "added stars" (Chinese: 增星, zēng xīng) while the stars from the
original catalogue are called "proper stars" (Chinese: 正星, zhèng xīng).

_The Continuation of Complete Studies of Astronomical Instruments_ has 3240
Stars names in total. Yi Shitong has conducted textual research and summary of
these records in his book _Chinese and Western Contrast Star Chart and
Catalogue 1950.0_ (Chinese: 中西对照恒星图表 1950.0, Zhōngxī Duìzhào Héngxīng Túbiǎo).


### Notes on Lunar Mansion

Traditional Chinese coordinates are given in "degrees right ascension" within a
lunar mansion. The star where the measurement starts for this lunar mansion is
called the determinative star (Chinese: 距星, jùxīng) of the mansions. The
equatorial degrees of the lodge (Chinese: 宿度, xiùdù) are all right ascensions
between the determinative star of a mansion the determinative star of the next
one. However, the traditional Chinese right ascension "degrees" are smaller
than in the sexagesimal system we are used to because the traditional Chinese
"degrees" reflect the motion of the mean Sun as one degree per day. Thus, a
Chinese "degree" is not 1/360 of the full circle but 1/365.25 of the circle.

The 28 mansion asterisms are grouped into Four Holy Beasts (Chinese: 象, xiàng),
each containing seven mansions corresponding to seven luminaries. The Four Holy
Beasts are the White Tiger of the East, The Red Bird of the South, the Azure
Dragon of the West and the Dark Warrier of the North. As they all lay around
the ecliptic, the association with the compass direction does not correspond to
the real horizon.

List of The Twenty-Eight Mansions:

|Seven Luminaries|        | Wood | Metal | Earth | Sun | Moon | Fire | Water |
|---------------|---------|------|-------|-------|-----|------|------|-------|
|Chinese Name    |东方苍龙 | 角宿 | 亢宿   | 氐宿   | 房宿 | 心宿  | 尾宿   | 箕宿   |
|Pinyin          |Dōngfāng Cānglóng |Jiǎoxiù |Kàngxiù |Dīxiù |Fángxiù |Xīnxiù |Wěixiù |Jīxiù |
|English Name    |Azure Dragon of the East |Horn Mansion |Neck Mansion |Root Mansion |Room Mansion |Heart Mansion |Tail Mansion |Winnowing Basket Mansion |
|Number of Xinguans | 46 | 11 | 7 | 11 | 7 | 2 | 5 | 3 |
|Determinative Star |  | α Vir | κ Vir | α2 Lib | π Sco | σ Sco | μ1 Sco | γ Sgr |

|Chinese Name    | 北方玄武  | 斗宿 | 牛宿 | 女宿 | 虚宿 | 危宿 | 室宿 | 壁宿 |
|---------------|---------|------|-------|-------|-----|------|------|-------|
|Pinyin | Běifāng Xuánwǔ | Dǒuxiù | Niúxiù | Nǚxiù | Xūxiù | Wēixiù | Shìxiù | Bìxiù |
|English Name | Black Tortoise of the North | Dipper Mansion | Ox Mansion | Girl Mansion | Emptiness Mansion | Rooftop Mansion | Encampment Mansion | Wall Mansion |
| Number of Xinguans | 65 | 10 | 11 | 8 | 10 | 10 | 10 | 6 |
|Determinative Star  |    |μ Sgr | β Cap | ε Aqr | β Aqr | α Aqr | α Peg | γ Peg |


| Chinese Name | 西方白虎 | 奎宿 | 娄宿 | 胃宿 | 昴宿 | 毕宿 | 觜宿 | 参宿 |
|---------------|---------|------|-------|-------|-----|------|------|-------|
| Pinyin |Xīfāng Báihǔ | Kuíxiù | Loúxiù | Wèixiù | Mǎoxiù | Bìxiù | Zīxiù | Shēnxiù |
|English Name | White Tiger of the West | Legs Mansion | Bond Mansion | Stomach Mansion | Hairy Head Mansion | Net Mansion | Turtle Beak Mansion | Three Stars Mansion |
| Number of Xinguans | 54 | 9 | 6 | 7 | 9 | 14 | 3 | 6 |
| Determinative Star |    | ζ And | β Ari | 35 Ari | 17 Tau | ε Tau | λ Ori | ζ Ori |

| Chinese Name | 南方朱雀 | 井宿 | 鬼宿 | 柳宿 | 星宿 | 张宿 | 翼宿 | 轸宿 |
|---------------|---------|------|-------|-------|-----|------|------|-------|
| Pinyin | Nánfāng Zhūquè | Jǐngxiù | Guǐxiù | Liǔxiù | Xīngxiù | Zhāngxiù | Yìxiù | Zhěnxiù |
| English Name | Vermilion Bird of the South | Well Mansion | Ghosts Mansion | Willow Mansion | Star Mansion | Extended Net Mansion | Wings Mansion | Chariot Mansion |
| Number of Xinguans | 42 | 19 | 7 | 2 | 5 | 2 | 2 | 5 |
| Determinative Star |  | μ Gem | θ Cnc | δ Hya | α Hya | υ1 Hya | α Crt | γ Crv |

### The Southern Asterisms

The sky around the south celestial pole was unknown to ancient Chinese.
Therefore, it was not included in the Three Enclosures and Twenty-Eight
Mansions system. However, by the end of the Ming Dynasty, Xu Guangqi
(Chinese:徐光启, Xú Guāngqǐ) introduced another 23 Xingguans based on the
knowledge of European star charts. These Xingguans were since incorporated into
the traditional Chinese star maps.

![](hunxiang.webp)
_Xingguans Map of Celestial Globe (Su Song，Song dynasty)_
{: .img_and_caption}

### Deep Space Objects

In ancient China, even some deep space objects were included in the Xingguans.

Include the following:

| General name | Chinese Name | Pinyin   | Chinese Name | Nick name |
|--------------|--------------|----------|--------------|-----------|
| NGC 6231     | 神宫          | shéngōng | God's Palace | Northern Jewel Box Cluster |
| NGC 6475/M 7 | 鱼           | Yú        | Fish         | Ptolemy Cluster |
| NGC 2632/M 44 | 积尸         | JīShī    | Cumulative Corpses | Beehive Cluster |
| NGC 5139     | 库楼增一      | Kùlóu Zēng I | Arsenal Added I | Omega Centauri |
| NGC 224/M 31 | 奎宿增廿一     | Kuíxiù Zēng XXI | Legs Mansion XXI | Andromeda Galaxy |
| NGC 3372     | 海山二        | Hǎishān II   | Sea and Mountain II  | Homunculus Nebula，Eta Carinae |

### Notes

This sky culture is based on the information in _Chinese and Western Contrast
Stars Chart and Star Catalogue 1950.0_ (Star Catalogue). (Chinese：
中西对照恒星图表1950.0(星表分册))，and _Complete Studies of Astronomical Instruments_
(Chinese： 仪象考成).

Special thanks to Liu Chunbin for the collation of the _Chinese and Western
Contrast Stars Chart and Star Catalogue 1950.0(Star Catalogue)_. He produced
Chinese Star Catalogue for Stellarium (Chinese： Stellarium 中国星官体系下中文星名扩展包) is a
very important reference.

For the translation of constellations, the use of the Hong Kong Space Museum
produced the English-Chinese Glossary of Chinese Star Regions, Asterisms and
Star Names (Chinese： 中国星区、星官及星名英译表). Only a small portion of the translation is
changed, for example, the translation of the two different Xingguans is the
same.

The cultural connotations of the name cannot be explained perfectly, because
thousands of years passed, the connotations behind some names are
controversial. These are only possible translations.

## References

 - [#1]: Sun Xiaochun and Jacob Kistemaker: The Chinese sky during the Han, Brill, Leiden, 2007
 - [#2]: Rufus, Carl and Tien, Hsing-Chih: The Soochow Astronomical Chart, University of Michigan Press, Ann Arbor, Michigan, USA, 1945
 - [#3]: The Suzhou map [digitized](http://www.chinesehsc.org/zoomify/suzhou_planisphere.html)
 - [#4]: English-Chinese Glossary of Chinese Star Regions, Asterisms and Star Names. [Link](http://www.lcsd.gov.hk/CE/Museum/Space/en_US/web/spm/starshine/resources/constemyth/glossary.html)
 - [#4]: AEEA Astronomy Education Information [Ancient Chinese constellation system](http://aeea.nmns.edu.tw/aeea/contents_list/star_sign.html)
 - [#5]: Chinese constellations: [Wikipedia article](http://en.wikipedia.org/wiki/Chinese_constellations)
 - [#6]: Traditional Chinese star names: [Wikipedia article](https://en.wikipedia.org/wiki/Traditional_Chinese_star_names)
 - [#7]: Purple Forbidden Enclosure: [Wikipedia article](https://en.wikipedia.org/wiki/Purple_Forbidden_enclosure)
 - [#8]: Supreme Palace Enclosure: [Wikipedia article](https://en.wikipedia.org/wiki/Supreme_Palace_enclosure)
 - [#9]: Heavenly Market Enclosure: [Wikipedia article](https://en.wikipedia.org/wiki/Heavenly_Market_enclosure)
 - [#10]: 28 Mansions: [Wikipedia article](https://en.wikipedia.org/wiki/Twenty-Eight_Mansions)
 - [#11]: _Complete Studies of Astronomical Instruments_ (Chinese： 仪象考成)

## Authors

This sky culture was initially contributed by _Karrie Berglund_ of Digitalis
Education Solutions, Inc. based on the Hong Kong Space Museum star maps.

Sun Shuwei contributed more than 200 Xingguans and more than 3,000 stars，based
primarily on the book _Chinese and Western Contrast Star Chart and Catalogue
1950.0_ by Yi Shitong.

Text rework by Stellarium's team.

## License

Su Song and Suzhou maps images: Public Domain

Text and line: CC BY-SA
