# Indian Vedic

## Introduction

Indian astronomy has a long history stretching from pre-historic to modern
times. Some of the earliest roots of Indian astronomy can be dated to the
period of Indus Valley Civilization or earlier.

## Description

The Vedic sky culture shows some similiarities with the Parthian one, e.g. some
commonly known constellations related to lunar mansions, called _Nakṣatra_-s.

### Rāśi (राशिः)

The sidereal zodiac is an imaginary belt of 360 degrees (like the tropical
zodiac), divided into 12 equal parts. Each twelfth part (of 30 degrees) is
called a sign or rashi. Their names are shown in (brackets).

In Vedic astronomy there are two systems of measuring time: the lunar calendar
and the solar calendar. In both cases one year is divided into 12 months or
"māsā". The names of the solar months originated from these constellation's
names.

### Nakṣatra (नक्षत्रम्)

In Hindu tradition the ecliptic is divided into 27 parts of approximately
13°20", mirroring the siderial month and corresponding to 27 asterisms known as
the _nakṣatra_-s [#4]. In the earliest extant layers of the tradition this
number was made 28. This division is critical for several purposes including
timing rituals and determining the birth lunar mansions. Since these asterisms
define an area in the sky, technically they are also constellations.

Surya Siddhanta and Vedanga-Jyotisha specify start coordinates for the 13°20"
divisions using some stars [#2].

The earliest complete lists of _nakṣatra_ are found in the _Taittirīya-śruti_
and the _Atharvaveda_ where they are recited as part of the _nakṣatreṣṭi_
ritual which places the deities of pantheon in these celestial compartments.
Some scholars opine that the tradition shows that by the early medieval period,
the _nakṣatra_ identification had changed to a small degree from the Vedic
period.

In mythology the Nakshatras are considered to be the 27 daughters of Daksha
Prajipati and wives of Chandra, the god of moon. Daksha found that Soma
(=Chandra) overly favored one daughter (rohinī) over the others, thus
neglecting their needs and flouting his responsibilities. For this, Daksha
cursed him to wither and die. Chandra Dev approached and worshipped Lord Shiva
in order to be relieved of the curse. He gave Chandra the boon that in a lunar
month, he would grow for fifteen days (or "Pakshā") in one half and in the
other half he would keep losing one shade (or "Kalā") per lunar day (or
"tithi") and decrease in size.

The names of the lunar months originated from those 12 division names in which
full moon or "Purnimā" occurs. Unlike a solar day which is defined by a sunrise
to next sunrise, a lunar day or moon's position in a nakshatra doesn't depends
on the Sun's or Moon's rise. Thus a lunar day may start at any time of a solar
day. Like other ancient human cultures, Vedic people invented a number of
systems for intercalation of lunar months, i.e. adding another month every 32.5
months on average or 4 months in every 11 years to correct the mismatch between
lunar and solar year.

| Solar Months | Lunar Months | Modern     | Season |
|--------------|--------------|------------|--------|
| Meṣa         | Vaiśakhā     | Apr-May    | Grīṣma (Summer) |
| Vṛṣabha      | Jyeṣṭha      | May–June   | Grīṣma (Summer) |
| Mithuna      | āṣāṛā        | June–July  | Varṣā (Monsoon) |
| Karkaṭa      | śrabaṇā      | July-Aug   | Varṣā (Monsoon) |
| Siṃha        | Bhādra       | Aug-Sept   | Śarad (Autumn) |
| Kanyā        | Aśvin        | Sept-Oct   | Śarad (Autumn) |
| Tulā         | Kārtik       | Oct-Nov    | Hemanta (Pre-Winter) |
| Vṛścika      | Agāhāna      | Nov-Dec    | Hemanta (Pre-Winter) |
| Dhanu        | Pauṣa        | Dec-Jan    | Śiśira (Winter) |
| Makara       | Magha        | Jan-Feb    | Śiśira (Winter) |
| Kumbha 	     | phālguna     | Feb-Mar    | Vasanta (Spring) |
| Mīna         | Chaitrā      | Mar-Apr    | Vasanta (Spring) |
|  -           | Adhikā       | Leap month |  -  |

A few of the _yogatārā_-s or prominent asterisms in the _nakṣatra_-s (going by
their mainstream identification) lie slightly outside their constellation
boundaries. In these cases, any resultant problem (with regards to ritual
timing or astrology) should be solved by other means, e.g. some people propose
alternate identifications for such _yogatārā_-s.

### Navagraha - Nine planets

They observed that some celestial bodies move independently relative to the
background stars; they named them planets or "graha". By this definition
(moving), the Sun and Moon are also treated as _graha_ or planet. The Vedic
also named the lunar nodes as planets as these points are very inportant to
calculate the eclipses. The name of Vedic days originated from these planet's
names.

| Graha | Designation | Name of Solar days |
|-------|-------------|--------------------|
| Sūrya (Sun) | Sun God | Ravivāsara (Sunday) |
| Chandra/Soma (Moon) | Moon god | Somavāsara (Monday) |
| Maṅgala (Mars) | God of war | Maṅgalavāsara (Twesday) |
| Budha (Mercury) | Son of Moon | Budhavāsara (Wednesday) |
| Bṛihaspati/Guru (Jupiter) | Teacher of Gods | Guruvāsara (Thursday) |
| Śukra (Venus) | Mentor of Demons | Śukravāsara (Friday) |
| Śani (Saturn) | God of Misfortune | Śanivāsara (Saturday) |
| Rahu | lunar node |  -  |
| Ketú | lunar node |  -  |


## References

 - [#1]: Saha, M.N. and Lahiri, N.C.: History of the Calendar, New Delhi 1992
 - [#2]: History Of Calendar-Panchanga: [Committee Report](https://archive.org/stream/HistoryOfCalendarPanchangaCommittee/History-of-Calendar-Panchanga-Committee#page/n77/mode/2up)
 - [#3]: Nakshatra: [article on Sanskrit Wikipedia](https://sa.wikipedia.org/wiki/नक्षत्रम्)
 - [#4]: Nakshatra: [article on English Wikipedia](https://en.wikipedia.org/wiki/Nakshatra)

## Authors

[Tanmoy Saha](https://groups.google.com/forum/#!forum/sanskrit-programmers), 
Vishvas Vasuki and contributors from the sanskrit-coders community: [github
page](https://github.com/sanskrit-coders).

Re-worked by Susanne M Hoffmann

## License

CC BY-SA
