# Western

## Introduction

The Western sky culture is used internationally by modern astronomers, and is
the official scheme of The International Astronomical Union. It has historical
roots in Ancient Greek astronomy, with influences from Islamic astronomy.

## Description

The Western sky culture divides the celestial sphere into 88 areas of various
sizes called _constellations_, each with precise boundary, issued by the
International Astronomical Union in 1922. These constellations have become the
standard way to describe the sky, replacing similar sets in other sky cultures
exhaustively in daily usage.

The constellations in use today are based mainly on ancient Greek
constellations depicted by Ptolemy in his book the _Almagest_ during the 2nd
century CE. In the subsequent centuries, this book has been translated from
Greek into Arabic (6th to 9th century) and later to medieval Latin. In the
Arabic more than in the Latin tradition, the Ptolemaic figures were enriched
and transformed by native Arabic constellations and star names.

In the 18th century, European astronomers suggested new constellations to fill
the gaps between northern constellations (e.g. the constellation of "the lynx"
for an area close to the Great Bear but with stars so faint that you would need
the eyes of a lynx to see them) and also created new constellations in the
southern part of the sky which had not been visible to Ptolemy. These new
constellations were usually named after new technical inventions of the early
modern period (e.g. a chemical machine, a balloon, an air pump) or exotic
animals (e.g. a chamaeleon, a tucan, a paradise bird). Among them many
constellations were also named with political consideration to honor certain
kings or patrons.

In the beginning of the 20th century, the IAU (International Astronomical
Union) aimed for a large clean-up: in 1922, it officially accepted the list of
88 constellation names. In 1928 it also defined precise constellation
boundaries [#1] still in use today.


## Extras

In the 2nd century CE, Ptolemy in Alexandria published a multi-volume book
which summarised the knowledge of the time, rooted in a tradition of
mathematical astronomy since Hipparchus (at least 265 year earlier). In the
subsequent centuries, this book has been translated from Greek into Arabic (6th
to 9th century), from Arabic into Latin, and later, from the original ancient
Greek into medieval Latin. Due to this transformation, it is now known under
the artificial name _Almagest_, derived from the Arabic title [#7].

The Almagest's star catalogue (book VII and VIII) has been depicted many times
in the Islamic as well as in the Christian astronomical traditions. Often, the
figures were re-drawn in order to adapt them to the taste of art of the epoch.
In the Arabic more than in the Latin tradition, the Ptolemaic figures were
enriched and transformed by native Arabic constellations and star names.
Therefore, this sky culture displays a modern descendant of the Ptolemaic one
with traces of translations, misunderstandings, transformations, and purposly
additions.

In 1603 the lawyer and hobby astronomer Johann Bayer from Augsburg, Germany,
made a new celestial atlas, called Uranometria [#2]. In this atlas, he
introduced a systematic naming of stars starting with alpha, the brightest,
beta, the second brightest, gamma, the third ... within a constellation.
Subsequently, it was established to name a star with a Greek letter and the
Latin constellation name in casus genitive.

In the 18th century, the century of great atlases (Flamsteed, Fortin, Bode:
[#3][#4]), new constellations were added to fill the gaps between northern
constellations. Additionally, there were suggestions to create new
constellations in the southern part of the sky which had not been visible to
Ptolemy. European astronomers visited the European colonies and instead of
asking the native people for their constellations, the Europeans were creative.
This way, many new technical inventions of the early modern period were
depicted in constellations (e.g. a chemical machine, a balloon, an air pump) as
well as exotic animals (e.g. a chamaeleon, a tucan, a paradise bird).

The problem was that sometimes astronomers did not agree with each other and,
thus, atlases showed deviations from each other.

After many centuries of astronomers taking liberties in interpretation of the
Ptolemaic original, there were many variants of constellations. As
constellations are a positioning system, i.e. astronomers describe positions in
the sky relative to stars and stars relative to constellations (like
"Betelgeuse", Orion's right shoulder), it is necessary to use constellation
names and star names uniformly all over the world.

In the "Fin de siècle", there were upcoming suggestions in the IAU to unify the
system of constellations and star names [#5].

As the IAU in 1928 only defined the boundaries of these areas [#4] and not the
way of drawing artwork within them, several sub-cultures of painting figures
and drawing simplified stickfigures were developed during the 20th and 21st
century. We provide some of them as further sky cultures.

### Constellations

These constellations are based mainly on the Ptolemaic tradition which had been
used in all three Abrahamitic religions and, thus, was common in the Near East,
in Europe and its colonies on all continents. However, between the ancient
Greek constellations there were gaps of areas with only faint stars belonging
to no constellation.[#8] In the Modern Epoch, several astronomers suggested
constellation figures for these gaps (e.g. the constellation of "the lynx" for
an area close to the Great Bear but with stars so faint that you would need the
eyes of a lynx to see them), among them many political constellations to the
honor of certain kings or patrons. In the beginning of the 20th century, the
IAU aimed for a huge clean-up.

In 1922, the IAU officially accepted the list of 88 constellation names and
their official abbreviations with three letters. The only remaining political
constellations is Scutum, the shield of a Polish king but without mentioning
the political reference anymore. The Belgian priest E. Delporte got the task to
define constellation boundaries according to coordinates. In 1928, he finished
the work and the IAU accepted his delimitations [#1].

These "constellations" are naked areas in the sky without any stick figures or
depictions [#5]. The borders simply follow the lines of right ascension and
declination. These constellations became the standard way to describe the sky,
replacing similar sets in other sky cultures exhaustively in daily usage.

Stellarium by default displays the precise RA-DEC-boundaries and a set of
artwork constellations on the basis of Ptolemaic figures but following our
contemporary taste of art.

### Proper names of stars

Ptolemy's star catalogue had the layout of a table listing the description of
the star's position in the constellation's figure, the ecliptical coordinates,
and the magnitude e.g.: "The star at the tip of the tail of Ursa Minor", "Gem 0
1/6, +66", "Mag 3".

In most cases, the star names evolved by astronomer's systematical
abbreviations of these descriptions, e.g. first astronomer abbreviated in a
text "tip of the tail", a next astronomer drew a map with less space and wrote
only "tail" next to the star and this name remained. With centuries, these
descriptions were translated into Arabic and Latin, and in some cases the
translators or writers make mistakes because of misreading or misspelling or
the Arabic words (e.g. the Arabic "yad al gauza", the hand of the giant woman,
to the common term "Betelgeuse").

However, there are also a few original Greek words like the red star "Antares",
the counterpart of Ares (Mars) and even a few original Babylonian terms like
"Shargaz", the Sting, in Scorpius. Our modern, most recent IAU star names [#6]
are a huge mixture, also with influences or even politically wanted additions
of star names from the none-Ptolemaic sky cultures, e.g. the traditional
Pingsing, a Chinese star name for a star in Hydra (its meaning is only "star",
a reminescence to his lonely position) or newly adopted star names from
Polynesian, Hawaiian, or Aboriginal cultures for names of stars with
exoplanets.

## References

 - [#1]: Delporte, Eugene: Delimitation scientifique des constellations (tables et cartes), Cambridge, 1930
 - [#2]: facsimile: Uranometria von Johannes Bayer, Kunstschätzeverlag, Gerchsheim, 2010
 - [#3]: facsimile: Die große Flamsteed Edition - Himmelskartographie nach John Flamsteed von 1776 bis 1805, Albireo Verlag, Köln, 2017
 - [#4]: Latußeck, Arndt and Hoffmann, Susanne M: "Ein nützliches Unternehmen", Albireo Verlag, Köln, 2017
 - [#5]: Constellation english names. [IAU Constellations Page](https://www.iau.org/public/themes/constellations/)
 - [#6]: IAU Working Group Star Names. [WGSN](https://www.iau.org/science/scientific_bodies/working_groups/280/)
 - [#7]: Grasshoff, Gerd: The History of Ptolemy's Star Catalogue, Springer, New York, 1990
 - [#8]: Hoffmann, Susanne M.: Hipparchs Himmelsglobus, Springer, Wiesbaden/ New York, 2017
 - [#9]: Constellation. [Article on Wikipedia](http://en.wikipedia.org/wiki/Constellation)
 - [#10]: Star Catalogue. [Article on Wikipedia](http://en.wikipedia.org/wiki/Star_catalogue)
 - [#11]: Constellation image library of the U.S. Naval Observatory and the Space Telescope Science Institute. Johannes Hevelius Engravings. [Link](http://hubblesource.stsci.edu/sources/illustrations/constellations/)

## Authors

Stellarium's team.

Illustrations by Johan Meuris.

## License

Text and data: CC BY-SA

Illustrations: Free Art License
